# eis-documents
The EMIL DocumentService API description

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 1.28.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.emil.de](https://www.emil.de)

## Requirements.

Python >=3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install eis.document
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/emilDev/eis-document-sdk.git`)

Then import the package:
```python
import eis.document
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import eis.document
```

## Getting Started

The environment variables must be set in order to properly use this SDK.

```shell 
export EMIL_USERNAME=XXXXXXX
export EMIL_PASSWORD=XXXXXXX
```

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
import time
import eis.document
from pprint import pprint
from eis.document.api import document_templates_api
from eis.document.model.create_doc_template_request_dto import CreateDocTemplateRequestDto
from eis.document.model.create_doc_template_response_class import CreateDocTemplateResponseClass
from eis.document.model.delete_response_class import DeleteResponseClass
from eis.document.model.get_doc_template_response_class import GetDocTemplateResponseClass
from eis.document.model.list_doc_templates_response_class import ListDocTemplatesResponseClass
from eis.document.model.update_doc_template_request_dto import UpdateDocTemplateRequestDto
from eis.document.model.update_doc_template_response_class import UpdateDocTemplateResponseClass
# Defining the host is optional and defaults to https://apiv2.emil.de
# See configuration.py for a list of all supported configuration parameters.
configuration = eis.document.Configuration(
    host = "https://apiv2.emil.de"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Bearer is automatically handled with exported environment variables. However, you
# can manuallay configure Bearer authorization (JWT): bearer
configuration = eis.document.Configuration(
    access_token = 'YOUR_BEARER_TOKEN'
)

# After manual token becomes invalid, the SDK will default to re-login automatically
# with environment variable credentials.


# Enter a context with an instance of the API client
with eis.document.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = document_templates_api.DocumentTemplatesApi(api_client)
    create_doc_template_request_dto = CreateDocTemplateRequestDto(
        name="SEPA template",
        slug="SEPA-template",
        layout_id=1,
        body_template=None,
        product_slug="car-insurance",
        label="SEPA-Lastschriftmandat",
    ) # CreateDocTemplateRequestDto | 
    authorization = "Authorization_example" # str | Bearer Token (optional)

    try:
        # Create the document template
        api_response = api_instance.create_doc_template(create_doc_template_request_dto, authorization=authorization)
        pprint(api_response)
    except eis.document.ApiException as e:
        print("Exception when calling DocumentTemplatesApi->create_doc_template: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://apiv2.emil.de*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DocumentTemplatesApi* | [**create_doc_template**](docs/DocumentTemplatesApi.md#create_doc_template) | **POST** /documentservice/v1/doc-templates | Create the document template
*DocumentTemplatesApi* | [**delete_doc_template**](docs/DocumentTemplatesApi.md#delete_doc_template) | **DELETE** /documentservice/v1/doc-templates/{id} | Delete the document template
*DocumentTemplatesApi* | [**get_doc_template**](docs/DocumentTemplatesApi.md#get_doc_template) | **GET** /documentservice/v1/doc-templates/{id} | Retrieve the document template
*DocumentTemplatesApi* | [**list_doc_templates**](docs/DocumentTemplatesApi.md#list_doc_templates) | **GET** /documentservice/v1/doc-templates | List document templates
*DocumentTemplatesApi* | [**update_doc_template**](docs/DocumentTemplatesApi.md#update_doc_template) | **PUT** /documentservice/v1/doc-templates/{id} | Update the document template
*DocumentsApi* | [**create_document**](docs/DocumentsApi.md#create_document) | **POST** /documentservice/v1/documents | Create the document
*DocumentsApi* | [**create_presigned_post**](docs/DocumentsApi.md#create_presigned_post) | **POST** /documentservice/v1/documents/pre-signed-post | Upload documents using pre-signed URL
*DocumentsApi* | [**delete_document**](docs/DocumentsApi.md#delete_document) | **DELETE** /documentservice/v1/documents/{code} | Delete the document
*DocumentsApi* | [**get_document_download_url**](docs/DocumentsApi.md#get_document_download_url) | **GET** /documentservice/v1/documents/{code}/download-url | Fetches a document download URL
*DocumentsApi* | [**get_signed_s3key_url**](docs/DocumentsApi.md#get_signed_s3key_url) | **GET** /documentservice/v1/documents/signed-s3-url | Fetches a presigned URL for a S3 key
*DocumentsApi* | [**list_documents**](docs/DocumentsApi.md#list_documents) | **GET** /documentservice/v1/documents | List documents
*DocumentsApi* | [**update_document**](docs/DocumentsApi.md#update_document) | **PUT** /documentservice/v1/documents/{code} | Update the document
*DocxTemplatesApi* | [**delete_docx_template**](docs/DocxTemplatesApi.md#delete_docx_template) | **DELETE** /documentservice/v1/docx-templates/{code} | Delete the docx template
*DocxTemplatesApi* | [**download_docx_template**](docs/DocxTemplatesApi.md#download_docx_template) | **GET** /documentservice/v1/docx-templates/{code}/download-url | Get pre-signed url for downloading docx template
*DocxTemplatesApi* | [**get_docx_template**](docs/DocxTemplatesApi.md#get_docx_template) | **GET** /documentservice/v1/docx-templates/{code} | Retrieve the docx template
*DocxTemplatesApi* | [**list_docx_templates**](docs/DocxTemplatesApi.md#list_docx_templates) | **GET** /documentservice/v1/docx-templates | List docx templates
*DocxTemplatesApi* | [**update_docx_template**](docs/DocxTemplatesApi.md#update_docx_template) | **PUT** /documentservice/v1/docx-templates/{code} | Update the docx template
*DocxTemplatesApi* | [**upload_docx_template**](docs/DocxTemplatesApi.md#upload_docx_template) | **POST** /documentservice/v1/docx-templates | Upload a docx template.
*LayoutsApi* | [**create_layout**](docs/LayoutsApi.md#create_layout) | **POST** /documentservice/v1/layouts | Create the layout
*LayoutsApi* | [**delete_layout**](docs/LayoutsApi.md#delete_layout) | **DELETE** /documentservice/v1/layouts/{id} | Delete the layout
*LayoutsApi* | [**get_layout**](docs/LayoutsApi.md#get_layout) | **GET** /documentservice/v1/layouts/{id} | Retrieve the layout
*LayoutsApi* | [**list_layouts**](docs/LayoutsApi.md#list_layouts) | **GET** /documentservice/v1/layouts | List layouts
*LayoutsApi* | [**update_layout**](docs/LayoutsApi.md#update_layout) | **PUT** /documentservice/v1/layouts/{id} | Update the layout
*ProductDocumentsApi* | [**delete_product_document**](docs/ProductDocumentsApi.md#delete_product_document) | **DELETE** /documentservice/v1/product-documents/{productSlug}/{code} | Delete the product document
*ProductDocumentsApi* | [**download_product_document**](docs/ProductDocumentsApi.md#download_product_document) | **GET** /documentservice/v1/product-documents/{productSlug}/{code}/download-url | Get pre-signed url for downloading product document
*ProductDocumentsApi* | [**get_product_document**](docs/ProductDocumentsApi.md#get_product_document) | **GET** /documentservice/v1/product-documents/{productSlug}/{code} | Retrieve the product document
*ProductDocumentsApi* | [**list_product_documents**](docs/ProductDocumentsApi.md#list_product_documents) | **GET** /documentservice/v1/product-documents/{productSlug} | List product documents
*ProductDocumentsApi* | [**upload_product_document**](docs/ProductDocumentsApi.md#upload_product_document) | **POST** /documentservice/v1/product-documents/{productSlug} | Create the product document
*SearchKeywordsApi* | [**list_search_keywords**](docs/SearchKeywordsApi.md#list_search_keywords) | **GET** /documentservice/v1/search-keywords | List keywords
*SearchableDocumentOwnersApi* | [**list_searchable_document_owners**](docs/SearchableDocumentOwnersApi.md#list_searchable_document_owners) | **GET** /documentservice/v1/searchable-document-owners | List searchable document owners
*SearchableDocumentsApi* | [**list_searchable_documents**](docs/SearchableDocumentsApi.md#list_searchable_documents) | **GET** /documentservice/v1/searchable-documents | List searchable documents
*DefaultApi* | [**check**](docs/DefaultApi.md#check) | **GET** /documentservice/health | Health Check


## Documentation For Models

 - [CreateDocTemplateRequestDto](docs/CreateDocTemplateRequestDto.md)
 - [CreateDocTemplateResponseClass](docs/CreateDocTemplateResponseClass.md)
 - [CreateDocumentRequestDto](docs/CreateDocumentRequestDto.md)
 - [CreateDocumentSyncResponseClass](docs/CreateDocumentSyncResponseClass.md)
 - [CreateHtmlTemplateDto](docs/CreateHtmlTemplateDto.md)
 - [CreateLayoutRequestDto](docs/CreateLayoutRequestDto.md)
 - [CreateLayoutResponseClass](docs/CreateLayoutResponseClass.md)
 - [CreatePresignedPostRequestDto](docs/CreatePresignedPostRequestDto.md)
 - [CreatePresignedPostResponseClass](docs/CreatePresignedPostResponseClass.md)
 - [DeleteLayoutRequestDto](docs/DeleteLayoutRequestDto.md)
 - [DeleteProductDocumentRequestDto](docs/DeleteProductDocumentRequestDto.md)
 - [DeleteRequestDto](docs/DeleteRequestDto.md)
 - [DeleteResponseClass](docs/DeleteResponseClass.md)
 - [DocTemplateClass](docs/DocTemplateClass.md)
 - [DocumentClass](docs/DocumentClass.md)
 - [DocxTemplateClass](docs/DocxTemplateClass.md)
 - [DownloadDocumentRequestDto](docs/DownloadDocumentRequestDto.md)
 - [GetDocTemplateRequestDto](docs/GetDocTemplateRequestDto.md)
 - [GetDocTemplateResponseClass](docs/GetDocTemplateResponseClass.md)
 - [GetDocumentDownloadUrlResponseClass](docs/GetDocumentDownloadUrlResponseClass.md)
 - [GetDocxTemplateDownloadUrlResponseClass](docs/GetDocxTemplateDownloadUrlResponseClass.md)
 - [GetDocxTemplateResponseClass](docs/GetDocxTemplateResponseClass.md)
 - [GetLayoutRequestDto](docs/GetLayoutRequestDto.md)
 - [GetLayoutResponseClass](docs/GetLayoutResponseClass.md)
 - [GetProductDocumentDownloadUrlResponseClass](docs/GetProductDocumentDownloadUrlResponseClass.md)
 - [GetProductDocumentResponseClass](docs/GetProductDocumentResponseClass.md)
 - [GetSignedS3KeyUrlResponseClass](docs/GetSignedS3KeyUrlResponseClass.md)
 - [GrpcCreateDocTemplateRequestDto](docs/GrpcCreateDocTemplateRequestDto.md)
 - [GrpcUpdateDocTemplateRequestDto](docs/GrpcUpdateDocTemplateRequestDto.md)
 - [HtmlTemplateClass](docs/HtmlTemplateClass.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse503](docs/InlineResponse503.md)
 - [LayoutClass](docs/LayoutClass.md)
 - [ListDocTemplateRequestDto](docs/ListDocTemplateRequestDto.md)
 - [ListDocTemplatesResponseClass](docs/ListDocTemplatesResponseClass.md)
 - [ListDocumentsResponseClass](docs/ListDocumentsResponseClass.md)
 - [ListDocxTemplatesResponseClass](docs/ListDocxTemplatesResponseClass.md)
 - [ListLayoutsResponseClass](docs/ListLayoutsResponseClass.md)
 - [ListProductDocumentsResponseClass](docs/ListProductDocumentsResponseClass.md)
 - [ListRequestDto](docs/ListRequestDto.md)
 - [ListSearchKeywordsRequestDto](docs/ListSearchKeywordsRequestDto.md)
 - [ListSearchKeywordsResponseClass](docs/ListSearchKeywordsResponseClass.md)
 - [ListSearchableDocumentOwnersRequestDto](docs/ListSearchableDocumentOwnersRequestDto.md)
 - [ListSearchableDocumentOwnersResponseClass](docs/ListSearchableDocumentOwnersResponseClass.md)
 - [ListSearchableDocumentsRequestDto](docs/ListSearchableDocumentsRequestDto.md)
 - [ListSearchableDocumentsResponseClass](docs/ListSearchableDocumentsResponseClass.md)
 - [ProductDocumentClass](docs/ProductDocumentClass.md)
 - [SearchableDocumentClass](docs/SearchableDocumentClass.md)
 - [SearchableDocumentOwnerClass](docs/SearchableDocumentOwnerClass.md)
 - [SharedUpdateDocxTemplateRequestDto](docs/SharedUpdateDocxTemplateRequestDto.md)
 - [UpdateDocTemplateRequestDto](docs/UpdateDocTemplateRequestDto.md)
 - [UpdateDocTemplateResponseClass](docs/UpdateDocTemplateResponseClass.md)
 - [UpdateDocumentRequestDto](docs/UpdateDocumentRequestDto.md)
 - [UpdateDocumentResponseClass](docs/UpdateDocumentResponseClass.md)
 - [UpdateDocxTemplateResponseClass](docs/UpdateDocxTemplateResponseClass.md)
 - [UpdateHtmlTemplateDto](docs/UpdateHtmlTemplateDto.md)
 - [UpdateLayoutRequestDto](docs/UpdateLayoutRequestDto.md)
 - [UpdateLayoutResponseClass](docs/UpdateLayoutResponseClass.md)
 - [UploadDocxTemplateRequestDto](docs/UploadDocxTemplateRequestDto.md)
 - [UploadProductDocumentRequestDto](docs/UploadProductDocumentRequestDto.md)


## Documentation For Authorization


## bearer

- **Type**: Bearer authentication (JWT)


## Author

kontakt@emil.de


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in eis.document.apis and eis.document.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from eis.document.api.default_api import DefaultApi`
- `from eis.document.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import eis.document
from eis.document.apis import *
from eis.document.models import *
```

